unit measure_GPIB;
// Powered by Jan H. Kuypers
// Berkeley Micromechanical Analysis and Design Group (BMAD)
// University of California at Berkeley, April 2008

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, GPIB, StdCtrls, Spin, ComCtrls, ExtCtrls;

type
  TForm1 = class(TForm)
    Button7: TButton;
    Memo1: TMemo;
    TreeView1: TTreeView;
    Button2: TButton;
    Label1: TLabel;
    Label2: TLabel;
    Panel1: TPanel;
    Panel2: TPanel;
    procedure Button2Click(Sender: TObject);
    procedure Button7Click(Sender: TObject);
    procedure StartUp(Sender: TObject);
    procedure ShutDown(Sender: TObject);
    procedure ShowDeviceInfo(Sender: TObject);
    procedure ListGPIB;
  private
    { Private declarations }
  public
    { Public declarations }
     // stores information for /instr number/GPIB addr/GPIB board no/
     // i.e. /INST0/Addr 25/Board ID0/
    INSTGPIBno : array [1..100, 1..3] of SmallInt;
    // node number of all GPIBBoards found
    GPIBBoardList : array [0..31] of Integer;
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.ListGPIB;
var
  boardID : Integer;
  DevFoundList : GPIB.AddrList;
  i,j,h, k,n : integer;
begin
  // My Computer super-node in TreeView
  TreeView1.Items.Clear;
  TreeView1.Items.Add(nil,'My Computer');
  // k keeps track of all equippment in the tree list
  k := 0;
  // h keeps track of GPIB board number
  h := 0;
  for i := 0 to 31 do    //for i := 0 to 31 do
  begin
    // Check if board ID exists
    If Not(FindBoard(i)=-1) then
    begin
      // count up additional equipmment entry in tree
      k := k+1;
      // GPIB parent node
      TreeView1.Items.AddChild(TreeView1.Items.Item[0],'GPIB'+IntToStr(i));
      // Get all devices connected to BoardID i
      DevFoundList := ListGPIBDevices(i);
      // Check for non-zero devices
      h := k;
      for j := 0 to 31 do
      begin
        if Not(DevFoundList[j]=0) then
        begin
          TreeView1.Items.AddChild(TreeView1.Items.Item[h],'INST'+IntToStr(j)+', Addr '+IntToStr(DevFoundList[j]));
          // count up additional equipmment entry in tree
          k := k+1;
          // Save INST number and GPIB number in array
          n := TreeView1.Items.Count-1;
          INSTGPIBno[n,1] := j;      //i.e. INST0
          INSTGPIBno[n,2] := DevFoundList[j];   //i.e. Addr = 25
          INSTGPIBno[n,3] := i;   // GPIB board ID it is connected to
        end;
      end;
    end;
    GPIBBoardList[i] := h;
  end;
end;

procedure TForm1.Button7Click(Sender: TObject);
begin
  //Refresh TreeView
  ListGPIB;
  // Clear Memo1
  Memo1.Lines.Clear;
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
   Halt;
end;

procedure TForm1.ShowDeviceInfo(Sender: TObject);
var
  SelectedID,i : Integer;
  INST : Boolean;
begin
  // Show device info
  SelectedID := TreeView1.Selected.AbsoluteIndex;
  //ShowMessage(IntToStr(SelectedID));
  //check whether selected node is GPIB board or INST
  INST := True;
  for i := 0 to 31 do
  begin
    INST := INST AND Not(SelectedID=GPIBBoardList[i]);
  end;
  if (SelectedID>1) and INST then
  begin
    Memo1.Lines.Clear;
    //ShowMessage(IntToStr(INSTGPIBno[SelectedID,1]));
    Memo1.Lines.Add('Device Name = INST'+IntToStr(INSTGPIBno[SelectedID,1]));
    Memo1.Lines.Add('GPIB Address = '+IntToStr(INSTGPIBno[SelectedID,2]));
    // Get ID message
    Memo1.Lines.Add(ReadGPIBString(INSTGPIBno[SelectedID,3],INSTGPIBno[SelectedID,2],'*IDN?'));
  end
  else
    Memo1.Lines.Clear;//clear Memo box
end;

procedure TForm1.ShutDown(Sender: TObject);
begin
  // clean Exit
  StopGPIB;
  Halt;
end;

procedure TForm1.StartUp(Sender: TObject);
begin
  //Start up GPIB when application starts
  StartUpGPIB;
  ListGPIB;
end;

end.
